@@ -1,5 +1,5 @@
 package Text::Markdown::PerlExtensions;
-$Text::Markdown::PerlExtensions::VERSION = '0.05';
+$Text::Markdown::PerlExtensions::VERSION = '0.06';
 use strict;
 use warnings;
 use 5.8.0;
@@ -285,7 +285,7 @@ for markdown syntax.
 
 =head1 REPOSITORY
 
-L<https://github.com/neilbowers/Text-Markdown-PerlExtensions>
+L<https://github.com/neilb/Text-Markdown-PerlExtensions>
 
 =head1 AUTHOR
 
